@@ -10,7 +10,7 @@ else
     EFIBOOT=""
 fi
 
-pushd $TMP_DIR/isofs >&8
+pushd $TMP_DIR/isofs >/dev/null
 # ebiso uses different command line options and parameters:
 if test "ebiso" = $( basename $ISO_MKISOFS_BIN ) ; then
     # ebiso currently works only with UEFI:
@@ -22,11 +22,11 @@ if test "ebiso" = $( basename $ISO_MKISOFS_BIN ) ; then
 else
     $ISO_MKISOFS_BIN $v -o "$ISO_DIR/$ISO_PREFIX.iso" -b isolinux/isolinux.bin -c isolinux/boot.cat \
         -no-emul-boot -boot-load-size 4 -boot-info-table \
-        -R -J -volid "$ISO_VOLID" $EFIBOOT -v -iso-level 3 .  >&8
-        ##-R -J -volid "$ISO_VOLID" $EFIBOOT  "${ISO_FILES[@]}"  >&8
+        -R -J -volid "$ISO_VOLID" $EFIBOOT -v -iso-level 3 .  >/dev/null
+        ##-R -J -volid "$ISO_VOLID" $EFIBOOT  "${ISO_FILES[@]}"  >/dev/null
 fi
 StopIfError "Could not create ISO image (with $ISO_MKISOFS_BIN)"
-popd >&8
+popd >/dev/null
 
 iso_image_size=( $(du -h "$ISO_DIR/$ISO_PREFIX.iso") )
 LogPrint "Wrote ISO image: $ISO_DIR/$ISO_PREFIX.iso ($iso_image_size)"
